{% extends 'garpix_page/base.html' %}

{% block content %}
<h1>{{ object.title }}</h1>

{% for obj in paginated_object_list %}
    <div>
        <p><a href="{{ obj.get_absolute_url }}">{{ obj.title }}</a></p>
    </div>
{% empty %}
    <div>Записей пока нет.</div>
{% endfor %}

{% include 'garpix_page/pagination.html' %}

{% endblock %}
